summaryrefslogtreecommitdiff
path: root/bin
diff options
context:
space:
mode:
Diffstat (limited to 'bin')
-rw-r--r--bin/first_stage.sh4
1 files changed, 3 insertions, 1 deletions
diff --git a/bin/first_stage.sh b/bin/first_stage.sh
index 1928386..a3a3240 100644
--- a/bin/first_stage.sh
+++ b/bin/first_stage.sh
@@ -140,9 +140,11 @@ echo "bash $REPOSITORY_PATH/bin/second_stage.sh $hostname \
${disk_path}1 $REPOSITORY_PATH" | arch-chroot /mnt
# Copy log from live image to root partition
cp $LOG_FILE_PATH /mnt$LOG_FILE_PATH
+mkdir /mnt$(dirname "$CONFIG_FILE_PATH")
+cp $CONFIG_FILE_PATH /mnt$CONFIG_FILE_PATH
# Unmount root partition
@@ -140,9 +140,11 @@ echo "bash $REPOSITORY_PATH/bin/second_stage.sh $hostname \
${disk_path}1 $REPOSITORY_PATH" | arch-chroot /mnt
-# Copy log from live image to root partition
+# Copy log and config from live image to root partition
cp $LOG_FILE_PATH /mnt$LOG_FILE_PATH